﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Content;

namespace XNA_Demo
{
    public class Enemy : GameObject
    {
        #region Declarations
        private float enemySpeed = 60.0f;
        public bool Dead = false;
        public bool facingLeft = true;
        public Vector2 currentTargetSquare;
        public Player player;
        #endregion

        #region Constructor
        public Enemy(ContentManager content, int cellX, int cellY, Player gamePlayer)
        {
            // death texture provided by: Reiner “Tiles” Prokein - http://www.reinerstilesets.de/
            // This is a different way to load images one strip at a time
            animations.Add("idle",
                new AnimationStrip(content.Load<Texture2D>(@"Textures\Sprites\Enemies\Zombie\Idle"),
                    48, "idle"));
            animations["idle"].LoopAnimation = true;
            animations.Add("run",
                new AnimationStrip(content.Load<Texture2D>(@"Textures\Sprites\Enemies\Zombie\Run"),
                    48, "run"));
            animations["run"].LoopAnimation = true;
            animations.Add("die",
                new AnimationStrip(content.Load<Texture2D>(@"Textures\Sprites\Enemies\Zombie\Die"),
                    48, "die"));
            animations["die"].LoopAnimation = true;

            // this is the size of the frame this image will occupy
            frameWidth = 32;
            frameHeight = 32;

            // the rectangle dimensions should equal the frame dimensions (i.e. 32 x 32)
            collisionRectangle = new Rectangle(13, 13, 6, 6);
            worldLocation = new Vector2(
                cellX * frameWidth,
                cellY * frameHeight);
            enabled = true;
            codeBasedBlocks = true;
            PlayAnimation("run");
            player = gamePlayer;
        }

        public Enemy(Texture2D enemyTexture, int cellX, int cellY, Player gamePlayer)
        {

            animations.Add("left",
                new AnimationStrip(enemyTexture, 50, 50, 0, "left"));
            animations["left"].LoopAnimation = true;
            animations.Add("downLeft",
                new AnimationStrip(enemyTexture, 50, 50, 1, "downLeft"));
            animations["downLeft"].LoopAnimation = true;
            animations.Add("downRight",
                new AnimationStrip(enemyTexture, 50, 50, 2, "downRight"));
            animations["downRight"].LoopAnimation = true;
            animations.Add("down",
                new AnimationStrip(enemyTexture, 50, 50, 3, "down"));
            animations["down"].LoopAnimation = true;
            animations.Add("upLeft",
                new AnimationStrip(enemyTexture, 50, 50, 4, "upLeft"));
            animations["upLeft"].LoopAnimation = true;
            animations.Add("upRight",
                new AnimationStrip(enemyTexture, 50, 50, 5, "upRight"));
            animations["upRight"].LoopAnimation = true;
            animations.Add("up",
                new AnimationStrip(enemyTexture, 50, 50, 6, "up"));
            animations["up"].LoopAnimation = true;
            animations.Add("right",
                new AnimationStrip(enemyTexture, 50, 50, 7, "right"));
            animations["right"].LoopAnimation = true;

            // this is the size of the frame this image will occupy
            frameWidth = 50;
            frameHeight = 50;

            // the rectangle dimensions should equal the frame dimensions (i.e. 32 x 32)
            collisionRectangle = new Rectangle(13, 13, 6, 6);
            enabled = true;
            codeBasedBlocks = true;
            //PlayAnimation("run");
            player = gamePlayer;
        }

        #endregion

        #region Public Methods
        public override void Update(GameTime gameTime)
        {
            string newAnimation = "idle";
            Vector2 oldLocation = worldLocation;
            if (!Dead)
            {
                Vector2 direction = this.getDirection();
                velocity = direction * enemySpeed;

                if ((direction.X < 0) && (direction.Y < 0))
                    newAnimation = "upLeft";
                if ((direction.X < 0) && ((direction.Y > -.05) && (direction.Y < .05)))
                    newAnimation = "left";
                if ((direction.X < 0) && (direction.Y > 0))
                    newAnimation = "downLeft";
                if ((direction.X > 0) && (direction.Y < 0))
                    newAnimation = "upRight";
                if ((direction.X > 0) && ((direction.Y > -.05) && (direction.Y < .05)))
                    newAnimation = "right";
                if ((direction.X > 0) && (direction.Y > 0))
                    newAnimation = "downRight";
                if (((direction.X > -.05) && (direction.X < .05)) && (direction.Y < 0))
                    newAnimation = "up";
                if (((direction.X > -.05) && (direction.X < .05)) && (direction.Y > 0))
                    newAnimation = "down";

                if (newAnimation != currentAnimation)
                {
                    PlayAnimation(newAnimation);
                }
            }
            base.Update(gameTime);
        }
        #endregion

        #region AI Methods
        public Vector2 getDirection()
        {
            Vector2 direction = player.WorldCenter - this.WorldCenter;
            direction.Normalize();

            return direction;
        }

        #endregion
    }
}

